# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

ENVIRONMENT_VARIABLES = [
    'CIRCLE_PROJECT_USERNAME',
    'CIRCLE_PROJECT_REPONAME',
    'CIRCLE_BRANCH',
    'CIRCLE_TAG',
    'CIRCLE_SHA1',
    'CIRCLE_REPOSITORY_URL',
    'CIRCLE_COMPARE_URL',
    'CIRCLE_BUILD_URL',
    'CIRCLE_BUILD_NUM',
    'CIRCLE_PREVIOUS_BUILD_NUM',
    'CI_PULL_REQUESTS',
    'CI_PULL_REQUEST',
    'CIRCLE_ARTIFACTS',
    'CIRCLE_USERNAME',
    'CIRCLE_TEST_REPORTS',
    'CIRCLE_PR_USERNAME',
    'CIRCLE_PR_REPONAME',
    'CIRCLE_PR_NUMBER',
    'CIRCLE_NODE_TOTAL',
    'CIRCLE_NODE_INDEX',
    'CIRCLE_BUILD_IMAGE']
