# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

ENVIRONMENT_VARIABLES = [
    'BUILD_NUMBER',
    'BUILD_ID',
    'BUILD_URL',
    'NODE_NAME',
    'JOB_NAME',
    'BUILD_TAG',
    'EXECUTOR_NUMBER',
    'JENKINS_URL',
    'JAVA_HOME',
    'WORKSPACE',
    'SVN_REVISION',
    'CVS_BRANCH',
    'GIT_COMMIT',
    'GIT_URL',
    'GIT_BRANCH']
